@@ -34,12 +34,13 @@ from airflow.providers.microsoft.azure.utils import (
     get_sync_default_azure_credential,
 )
 
-MessageCallback = Callable[[ServiceBusMessage], None]
-
-
 if TYPE_CHECKING:
     from azure.identity import DefaultAzureCredential
 
+    from airflow.utils.context import Context
+
+    MessageCallback = Callable[[ServiceBusMessage, Context], None]
+
 
 class BaseAzureServiceBusHook(BaseHook):
     """
@@ -251,9 +252,11 @@ class MessageHook(BaseAzureServiceBusHook):
             raise TypeError("Queue name cannot be None.")
         if not messages:
             raise ValueError("Messages list cannot be empty.")
-        with self.get_conn() as service_bus_client, service_bus_client.get_queue_sender(
-            queue_name=queue_name
-        ) as sender, sender:
+        with (
+            self.get_conn() as service_bus_client,
+            service_bus_client.get_queue_sender(queue_name=queue_name) as sender,
+            sender,
+        ):
             if isinstance(messages, str):
                 if not batch_message_flag:
                     msg = ServiceBusMessage(messages)
@@ -281,6 +284,7 @@ class MessageHook(BaseAzureServiceBusHook):
     def receive_message(
         self,
         queue_name: str,
+        context: Context,
         max_message_count: int | None = 1,
         max_wait_time: float | None = None,
         message_callback: MessageCallback | None = None,
@@ -298,19 +302,22 @@ class MessageHook(BaseAzureServiceBusHook):
         if queue_name is None:
             raise TypeError("Queue name cannot be None.")
 
-        with self.get_conn() as service_bus_client, service_bus_client.get_queue_receiver(
-            queue_name=queue_name
-        ) as receiver, receiver:
+        with (
+            self.get_conn() as service_bus_client,
+            service_bus_client.get_queue_receiver(queue_name=queue_name) as receiver,
+            receiver,
+        ):
             received_msgs = receiver.receive_messages(
                 max_message_count=max_message_count, max_wait_time=max_wait_time
             )
             for msg in received_msgs:
-                self._process_message(msg, message_callback, receiver)
+                self._process_message(msg, context, message_callback, receiver)
 
     def receive_subscription_message(
         self,
         topic_name: str,
         subscription_name: str,
+        context: Context,
         max_message_count: int | None,
         max_wait_time: float | None,
         message_callback: MessageCallback | None = None,
@@ -335,18 +342,23 @@ class MessageHook(BaseAzureServiceBusHook):
             raise TypeError("Subscription name cannot be None.")
         if topic_name is None:
             raise TypeError("Topic name cannot be None.")
-        with self.get_conn() as service_bus_client, service_bus_client.get_subscription_receiver(
-            topic_name, subscription_name
-        ) as subscription_receiver, subscription_receiver:
+        with (
+            self.get_conn() as service_bus_client,
+            service_bus_client.get_subscription_receiver(
+                topic_name, subscription_name
+            ) as subscription_receiver,
+            subscription_receiver,
+        ):
             received_msgs = subscription_receiver.receive_messages(
                 max_message_count=max_message_count, max_wait_time=max_wait_time
             )
             for msg in received_msgs:
-                self._process_message(msg, message_callback, subscription_receiver)
+                self._process_message(msg, context, message_callback, subscription_receiver)
 
     def _process_message(
         self,
         msg: ServiceBusReceivedMessage,
+        context: Context,
         message_callback: MessageCallback | None,
         receiver: ServiceBusReceiver,
     ):
@@ -364,7 +376,7 @@ class MessageHook(BaseAzureServiceBusHook):
             receiver.complete_message(msg)
         else:
             try:
-                message_callback(msg)
+                message_callback(msg, context)
             except Exception as e:
                 self.log.error("Error processing message: %s", e)
                 receiver.abandon_message(msg)
